@@ -1,4 +1,5 @@
 import requests
+from pathlib import Path
 
 import pynando.data
 
@@ -8,10 +9,12 @@ def default_download_dir():
 
 
 class Downloader(object):
-    def __init__(self, download_dir=None):
+    def __init__(self, download_dir: Path=None):
         self._download_dir = download_dir
         if self._download_dir is None:
             self._download_dir = default_download_dir()
+        if not self._download_dir.exists():
+            self._download_dir.mkdir()
 
     def download(self):
         print('download nando data')
@@ -24,8 +27,6 @@ class Downloader(object):
         for url in url_list:
             fname = url.split('/')[-1]
             fp = self._download_dir / fname
-            if fp.exists():
-                continue
 
             print('downloading {}'.format(fname))
             res = requests.get(url)
